<?php

namespace App\Http\Controllers\admin;
use PDF;
use App\Models\Submission;
use App\Models\Product;
use App\Models\Category;
use Illuminate\Http\Request;
use App\Http\Controllers\Controller;

class SubmissionController extends Controller
{
    /**
     * Display a listing of the resource.
     *
     * @return \Illuminate\Http\Response
     */
    public function index(Request $request)
    {
        $submissions = Submission::query();
        if ($request->search) {
            $search = $request->search;
           $submissions->where(function ($query) use ($search, $submissions) {
                $submissions->where('name', 'LIKE', "%{$search}%");
           });
        }
        $submissions = $submissions->whereStatus('created')->latest()->paginate(50);
        return view('admin.submission.all', compact(['submissions']));
    }

    /**
     * Show the form for creating a new resource.
     *
     * @return \Illuminate\Http\Response
     */
    public function create()
    {


        return view('admin.submission.create');
    }

    /**
     * Store a newly created resource in storage.
     *
     * @param  \Illuminate\Http\Request  $request
     * @return \Illuminate\Http\Response
     */
    public function store(Request $request)
    {
        // dd($request->all());
        $data=$request->validate([
            'name'=>'required',
            'note'=>'nullable',
            'room_id'=>'required',
            'release'=>'required',
            'categories'=>'required',
            'products'=>'required',
            'quantities'=>'required',
        ]);
        $user=auth()->user();
        $data['status'] = 'created';
        $submission= $user->submissions()->create($data);
        for ($i = 0; $i <sizeof(  $data['products']); $i++){
           $product=Product::find($data['products'][$i]);
           $price=$product->price;
        //    $category=Category::find($data['categories'][$i]);
        $product=$data['products'][$i];
        $category=$data['categories'][$i];
        $quantity=$data['quantities'][$i];
        $total=$price*$quantity;
        $submission->products()->attach($product,['category_id'=> $category,'quantity'=>$quantity,'price'=>$price,'total'=>$total]);
        }
        $submission->update(['sum'=>$submission->products->sum('pivot.total')]);
        alert()->success(' New  submission created' );
        return redirect()->route('submission.index');
    }

    /**
     * Display the specified resource.
     *
     * @param  int  $id
     * @return \Illuminate\Http\Response
     */
    public function show(Submission $submission ,Request $request)
    {
        $categories=array_unique($submission->products->pluck('category_id')->toArray() );
        $pdf=$request->pdf;
        if($request->pdf){
            $html = view('admin.submission.show', compact(['categories', 'submission','pdf']))->render();
            $pdf = PDF::loadHTML($html);
            $name =  'submission_'.$submission->id ;
            return $pdf->download("$name.pdf");
        }
        return view('admin.submission.show', compact(['submission','categories','pdf']));
    }

    /**
     * Show the form for editing the specified resource.
     *
     * @param  int  $id
     * @return \Illuminate\Http\Response
     */
    public function edit(Submission $submission)
    {
        return view('admin.submission.edit',compact(['submission']));
    }

    /**
     * Update the specified resource in storage.
     *
     * @param  \Illuminate\Http\Request  $request
     * @param  int  $id
     * @return \Illuminate\Http\Response
     */
    public function update(Request $request, Submission $submission)
    {

        $data=$request->validate([
            'name'=>'required',
            'note'=>'nullable',
            'release'=>'required',
            'categories'=>'required',
            'products'=>'required',
            'quantities'=>'required',
        ]);
        $user=auth()->user();
        $data['status'] = 'created';
        $submission->products()->sync([]);
        for ($i = 0; $i <sizeof(  $data['products']); $i++){
           $product=Product::find($data['products'][$i]);
           $price=$product->price;
        //    $category=Category::find($data['categories'][$i]);
        $product=$data['products'][$i];
        $category=$data['categories'][$i];
        $quantity=$data['quantities'][$i];
        $total=$price*$quantity;
        $submission->products()->attach($product,['category_id'=> $category,'quantity'=>$quantity,'price'=>$price,'total'=>$total]);
        }
        $submission->update(['sum'=>$submission->products->sum('pivot.total')]);
    $submission->update($data);
    alert()->success('   submission updated' );
    return redirect()->route('submission.index');
    }

    /**
     * Remove the specified resource from storage.
     *
     * @param  int  $id
     * @return \Illuminate\Http\Response
     */
    public function destroy(Submission $submission)
    {
        // $submission->products()->sync([]);
        // $submission->delete();
        // alert()->success(' submission deleted');
        // return redirect()->route('submission.index');
    }
}
