<?php

namespace App\Http\Controllers\admin;
use PDF;
use App\Models\Order;
use App\Models\Product;
use App\Models\Category;
use Illuminate\Http\Request;
use App\Http\Controllers\Controller;

class OrderController extends Controller
{
    /**
     * Display a listing of the resource.
     *
     * @return \Illuminate\Http\Response
     */
    public function index(Request $request)
    {
        $orders = Order::query();
        $user=auth()->user();
        if ($request->search) {
            $search = $request->search;
           $orders->where(function ($query) use ($search, $orders) {
                $orders->where('name', 'LIKE', "%{$search}%");
           });
        }
        $status=$request->status? $request->status:'created';
        if($request->status){
            $orders->whereStatus($status);
        }
        if( $user->role=='teacher'){
            $orders->where('user_id',$user->id);
        }
        if( $request->from){
            $orders->where('release','>=',$request->from);
        }
         if( $request->to){
            $orders->where('release','<=',$request->to);
        }
        $orders = $orders ->latest()->paginate(50);
        return view('admin.order.all', compact(['orders']));
    }

    /**
     * Show the form for creating a new resource.
     *
     * @return \Illuminate\Http\Response
     */
    public function create()
    {


        return view('admin.order.create');
    }

    /**
     * Store a newly created resource in storage.
     *
     * @param  \Illuminate\Http\Request  $request
     * @return \Illuminate\Http\Response
     */
    public function store(Request $request)
    {
        // dd($request->all());
        $data=$request->validate([
            'name'=>'required',
            'note'=>'nullable',
            'room_id'=>'required',
            'release'=>'required',
            'categories'=>'required',
            'products'=>'required',
            'quantities'=>'required',
        ]);
        $user=auth()->user();
        $data['status'] = 'created';
        $order= $user->orders()->create($data);
        for ($i = 0; $i <sizeof(  $data['products']); $i++){
           $product=Product::find($data['products'][$i]);
           $price=$product->price;
        //    $category=Category::find($data['categories'][$i]);
        $product=$data['products'][$i];
        $category=$data['categories'][$i];
        $quantity=$data['quantities'][$i];
        $total=$price*$quantity;
        $order->products()->attach($product,['category_id'=> $category,'quantity'=>$quantity,'price'=>$price,'total'=>$total]);
        }
        $order->update(['sum'=>$order->products->sum('pivot.total')]);
        alert()->success(' New  order created' );
        return redirect()->route('order.index');
    }

    /**
     * Display the specified resource.
     *
     * @param  int  $id
     * @return \Illuminate\Http\Response
     */
    public function show(Order $order ,Request $request)
    {
        $categories=array_unique($order->products->pluck('category_id')->toArray() );
        $pdf=$request->pdf;
        if($request->pdf){
            $html = view('admin.order.show', compact(['categories', 'order','pdf']))->render();
            $pdf = PDF::loadHTML($html);
            $name =  'order_'.$order->id ;
            return $pdf->download("$name.pdf");
            dd(30);

        }
        return view('admin.order.show', compact(['order','categories','pdf']));
    }

    /**
     * Show the form for editing the specified resource.
     *
     * @param  int  $id
     * @return \Illuminate\Http\Response
     */
    public function edit(Order $order)
    {
        if(  $order->status!='created'){
            alert()->error('Order has been locked');
            return redirect()->route('order.index');
        }
        return view('admin.order.edit',compact(['order']));
    }

    /**
     * Update the specified resource in storage.
     *
     * @param  \Illuminate\Http\Request  $request
     * @param  int  $id
     * @return \Illuminate\Http\Response
     */
    public function update(Request $request, Order $order)
    {
        if(  $order->status!='created'){
            alert()->error('Order has been locked');
            return redirect()->route('order.index');
        }
        if($request->duplicate){
            $new_order = $order->replicate();
            $new_order->push();
            foreach($order->products as $product){
                $new_order->products()->attach($product,['category_id'=> $product->pivot->category_id,'quantity'=> $product->pivot->quantity,'price'=>$product->pivot->price,'total'=>$product->pivot->total]);
            }
             $user=auth()->user();
            $new_order->update(['name' => "new copy of".$order->id, "user_id"=>$user->id]);
      
            alert()->success('order duplicated. Now edit new order');
            return redirect()->route('order.edit',$new_order->id);
        }

        $data=$request->validate([
            'name'=>'required',
            'note'=>'nullable',
            'room_id'=>'required',
            'release'=>'required',
            'categories'=>'required',
            'products'=>'required',
            'quantities'=>'required',
        ]);
        $user=auth()->user();
        $data['status'] = 'created';
        $order->products()->sync([]);
        for ($i = 0; $i <sizeof(  $data['products']); $i++){
           $product=Product::find($data['products'][$i]);
           $price=$product->price;
        //    $category=Category::find($data['categories'][$i]);
        $product=$data['products'][$i];
        $category=$data['categories'][$i];
        $quantity=$data['quantities'][$i];
        $total=$price*$quantity;

        $order->products()->attach($product,['category_id'=> $category,'quantity'=>$quantity,'price'=>$price,'total'=>$total]);
        }
        $order->update(['sum'=>$order->products->sum('pivot.total')]);
    $order->update($data);
    alert()->success('   order updated' );
    return redirect()->route('order.index');
    }

    /**
     * Remove the specified resource from storage.
     *
     * @param  int  $id
     * @return \Illuminate\Http\Response
     */
    public function destroy(Order $order)
    {
        if($order->status=='merged'){
            alert()->error('order has already been merged');
return redirect()->route('order.index');
        }
        $order->products()->sync([]);
        $order->delete();
        alert()->success(' order deleted');
        return redirect()->route('order.index');
    }
}
