<?php

namespace App\Http\Controllers\admin;

use App\Models\Product;
use App\Models\Category;
use Illuminate\Http\Request;
use App\Http\Controllers\Controller;

class ProductController extends Controller
{
     /**
     * Display a listing of the resource.
     *
     * @return \Illuminate\Http\Response
     */
    public function index(Request $request)
    {
        $products = Product::query();
        if ($request->search) {
            $search = $request->search;
           $products->where(function ($query) use ($search, $products) {
                $products->where('name', 'LIKE', "%{$search}%");
           });
        }
        $products = $products->latest()->paginate(50);
        return view('admin.product.all', compact(['products']));
    }

    /**
     * Show the form for creating a new resource.
     *
     * @return \Illuminate\Http\Response
     */
    public function create()
    {


        return view('admin.product.create');
    }

    /**
     * Store a newly created resource in storage.
     *
     * @param  \Illuminate\Http\Request  $request
     * @return \Illuminate\Http\Response
     */
    public function store(Request $request)
    {
        // dd($request->all());
        $data=$request->validate([
            'name'=>'required|min:3|unique:products,name',
            'price'=>'required|numeric',
            'category_id'=>'required|exists:categories,id',
            'supplier_id'=>'required|exists:suppliers,id',
            'active'=>'required',
        ]);
        $user=auth()->user();
        $user->products()->create($data);
        alert()->success(' New  product created' );
        return redirect()->route('product.index');
    }

    /**
     * Display the specified resource.
     *
     * @param  int  $id
     * @return \Illuminate\Http\Response
     */
    public function show(Product $product)
    {
        return view('admin.product.show', compact(['product']));
    }

    /**
     * Show the form for editing the specified resource.
     *
     * @param  int  $id
     * @return \Illuminate\Http\Response
     */
    public function edit(Product $product)
    {
        return view('admin.product.edit',compact(['product']));
    }

    /**
     * Update the specified resource in storage.
     *
     * @param  \Illuminate\Http\Request  $request
     * @param  int  $id
     * @return \Illuminate\Http\Response
     */
    public function update(Request $request, Product $product)
    {
        $data=$request->validate([
            'name'=>'required|min:3|unique:products,name,'.$product->id,
            'price'=>'required|numeric',
            'category_id'=>'required|exists:categories,id',
            'supplier_id'=>'required|exists:suppliers,id',
            'active'=>'required',
        ]);
    $product->update($data);
    // dd(  $product);

    alert()->success('   product updated' );
    return redirect()->route('product.index');
    }

    /**
     * Remove the specified resource from storage.
     *
     * @param  int  $id
     * @return \Illuminate\Http\Response
     */
    public function destroy($id)
    {
        //
    }

    public function get_product(Category $category)
    {
        $user=auth()->user();
        $all_products=Product::whereActive(1)->get();
        return response()->json([
            'body' => view('admin.product.get_product',compact(['category','all_products']))->render(),
        ]);
    }
}
