<?php

namespace App\Http\Controllers\admin;

use App\Models\Chat;
use App\Models\City;
use App\Models\User;
use App\Models\Travel;
use Illuminate\Http\Request;
use App\Http\Controllers\Controller;
use Intervention\Image\Facades\Image;
use Illuminate\Support\Facades\Validator;

class UserController extends Controller
{
    /**
     * Display a listing of the resource.
     *
     * @return \Illuminate\Http\Response
     */
    public function index(Request $request)
    {
        $users = User::query();
        if ($request->search) {
            $search = $request->search;
           $users->where(function ($query) use ($search, $users) {
                $users->where('name', 'LIKE', "%{$search}%")
                ->orWhere('email', 'LIKE', "%{$search}%")
                ->orWhere('username', 'LIKE', "%{$search}%")
                ->orWhere('phone', 'LIKE', "%{$search}%");
           });
        }
        // $users->whereIn('role', ['admin'])
        $users = $users->latest()->paginate(50);
        return view('admin.user.all', compact(['users']));
    }

    /**
     * Show the form for creating a new resource.
     *
     * @return \Illuminate\Http\Response
     */
    public function create()
    {


        return view('admin.user.create');
    }

    /**
     * Store a newly created resource in storage.
     *
     * @param  \Illuminate\Http\Request  $request
     * @return \Illuminate\Http\Response
     */
    public function store(Request $request)
    {
        // dd($request->all());
        $data=$request->validate([
            'name'=>'required|min:3',
            'email'=>'required|email|unique:users,email',
            'phone'=>'required|unique:users,phone',
            'role'=>'required',
            'username'=>'required|min:3|unique:users,username',
            'password'=>'required|min:6',
            'password' => 'required|confirmed|min:6',
            'active' => 'nullable',
        ]);
        $user=User::create($data);
        $user->assignRole( $data['role'] );
        alert()->success(' New  user created' );
        return redirect()->route('user.index');
    }

    /**
     * Display the specified resource.
     *
     * @param  int  $id
     * @return \Illuminate\Http\Response
     */
    public function show(User $user)
    {
        return view('admin.user.show', compact(['user']));
    }

    /**
     * Show the form for editing the specified resource.
     *
     * @param  int  $id
     * @return \Illuminate\Http\Response
     */
    public function edit(User $user)
    {
        return view('admin.user.edit',compact(['user']));
    }

    /**
     * Update the specified resource in storage.
     *
     * @param  \Illuminate\Http\Request  $request
     * @param  int  $id
     * @return \Illuminate\Http\Response
     */
    public function update(Request $request, User $user)
    {

        $data=$request->validate([
            'name'=>'required|min:3',
            'email'=>'required|email|unique:users,email,'.$user->id,
            'phone'=>'required|unique:users,phone,'.$user->id,
            'role'=>'required',
            'username'=>'required|min:3|unique:users,username,'.$user->id,
            'password'=>'required|min:6',
            'password' => 'required|confirmed|min:6',
            'active' => 'nullable',
        ]);
    $user->update($data);
    $user->assignRole( $data['role'] );
    alert()->success('   user updated' );
    return redirect()->route('user.index');
    }

    /**
     * Remove the specified resource from storage.
     *
     * @param  int  $id
     * @return \Illuminate\Http\Response
     */
    public function destroy($id)
    {
        //
    }






}
